@@ -83,7 +83,7 @@ sub __build_options {
                  keys %{ $options_data }) {
       my $option = $options_data->{ $name }; my $doc = $option->{doc};
 
-      not defined $doc and $doc = "No help for ${name}";
+      defined $doc or $doc = "No help for ${name}";
       push @options, [ __option_specification( $name, $option ), $doc ];
       defined $option->{autosplit} or next;
       $splitters->{ $name } = Data::Record->new( {
@@ -127,7 +127,7 @@ sub __option_specification {
    my $dash_name   = $name; $dash_name =~ tr/_/-/; # Dash name support
    my $option_spec = $dash_name;
 
-   defined $opt->{short} and $option_spec .= '|'.$opt->{short};
+   defined $opt->{short } and $option_spec .= '|'.$opt->{short};
    $opt->{repeatable} and not defined $opt->{format} and $option_spec .= '+';
    $opt->{negateable} and $option_spec .= '!';
    defined $opt->{format} and $option_spec .= '='.$opt->{format};
@@ -256,7 +256,7 @@ Larry Wall - For the Perl programming language
 
 =head1 Author
 
-Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
+Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
